==> vue-user-contact-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/user-contact/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import UserHead from "@dftvue2-opentiny/vue-user-head";
import CardTemplate from "@dftvue2-opentiny/vue-card-template";
import Espace from "@dftvue2-opentiny/vue-espace";
import Popover from "@dftvue2-opentiny/vue-popover";
import { IconChevronUp, IconChevronDown } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["data", "showArrow", "espace", "showName", "showNumber", "showImg", "placement", "popperClass", "popperAppendToBody", "isNewImMode"]),
  components: {
    UserHead,
    CardTemplate,
    Espace,
    Popover,
    IconChevronUp: IconChevronUp(),
    IconChevronDown: IconChevronDown()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-user-contact"
  }, [_c("Popover", {
    attrs: {
      "placement": "bottom-start",
      "trigger": "hover",
      "popper-class": "tiny-user-contact" + (_vm.showArrow ? " showArrow" : "") + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "append-to-body": _vm.popperAppendToBody,
      "visible-arrow": _vm.showArrow
    },
    on: {
      "show": function show($event) {
        _vm.show = true;
      },
      "hide": function hide($event) {
        _vm.show = false;
      }
    },
    scopedSlots: _vm._u([{
      key: "reference",
      fn: function fn() {
        return [_c("a", {
          staticClass: "dropdown-part",
          attrs: {
            "href": _vm.getUserHref()
          },
          on: {
            "click": _vm.doUserAction
          }
        }, [_c("user-head", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showImg,
            expression: "showImg"
          }],
          attrs: {
            "min": true,
            "round": true,
            "type": "image"
          },
          model: {
            value: _vm.data.imgUrl,
            callback: function callback($$v) {
              _vm.$set(_vm.data, "imgUrl", $$v);
            },
            expression: "data.imgUrl"
          }
        }), _c("div", {
          staticClass: "tiny-user-contact__role"
        }, [_c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showName,
            expression: "showName"
          }],
          staticClass: "tiny-user-contact__role-name"
        }, [_vm._v(_vm._s(_vm.data.userName))]), _c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showNumber,
            expression: "showNumber"
          }],
          staticClass: "tiny-user-contact__role-number"
        }, [_vm._v(_vm._s(_vm.data.roleNumber))])])], 1), _c(_vm.show ? "icon-chevron-up" : "icon-chevron-down", {
          tag: "component",
          staticClass: "tiny-svg-size tiny-user-contact__arrow"
        })];
      },
      proxy: true
    }])
  }, [_vm.slots.default ? _c("card-template", {
    staticClass: "tiny-user-contact__main",
    attrs: {
      "tools": _vm.data.tools
    }
  }, [_vm._t("default")], 2) : _c("card-template", {
    staticClass: "tiny-user-contact__main",
    attrs: {
      "tools": _vm.data.tools
    },
    scopedSlots: _vm._u([{
      key: "header",
      fn: function fn() {
        return [_c("div", {
          staticClass: "tiny-user-contact__header"
        }, [_c("div", {
          staticClass: "tiny-user-contact__title"
        }, [_c("user-head", {
          attrs: {
            "round": true,
            "type": "image"
          },
          model: {
            value: _vm.data.imgUrl,
            callback: function callback($$v) {
              _vm.$set(_vm.data, "imgUrl", $$v);
            },
            expression: "data.imgUrl"
          }
        }), _c("div", {
          staticClass: "tiny-user-contact__role"
        }, [_c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showName,
            expression: "showName"
          }],
          staticClass: "tiny-user-contact__role-name"
        }, [_vm._v(_vm._s(_vm.data.userName))]), _c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showNumber,
            expression: "showNumber"
          }],
          staticClass: "tiny-user-contact__role-number"
        }, [_vm._v(" " + _vm._s(_vm.t("ui.usercard.empno")) + "：" + _vm._s(_vm.data.roleNumber) + " ")])])], 1)])];
      },
      proxy: true
    }])
  }, [_c("div", [_c("div", {
    staticClass: "tiny-user-contact__message"
  }, _vm._l(_vm.data.values, function(item) {
    return _c("div", {
      key: item.text,
      staticClass: "tiny-user-contact__state"
    }, [_c("span", {
      staticClass: "tiny-user-contact__state-left"
    }, [_vm._v(_vm._s(item.text) + "：")]), _c("span", {
      staticClass: "tiny-user-contact__state-right"
    }, [_vm._v(_vm._s(item.value))])]);
  }), 0), _vm.espace && _vm.espace.length ? _c("espace", {
    attrs: {
      "data": _vm.espace
    }
  }) : _vm._e()], 1)])], 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-user-contact-2.24.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/user-contact/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import UserHead from '@opentinyvue/vue-user-head';
import CardTemplate from '@opentinyvue/vue-card-template';
import Espace from '@opentinyvue/vue-espace';
import Popover from '@opentinyvue/vue-popover';
import { IconChevronUp, IconChevronDown } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["data", "showArrow", "espace", "showName", "showNumber", "showImg", "placement", "popperClass", "popperAppendToBody", "isNewImMode"]),
  components: {
    UserHead,
    CardTemplate,
    Espace,
    Popover,
    IconChevronUp: IconChevronUp(),
    IconChevronDown: IconChevronDown()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-user-contact"
  }, [_c("Popover", {
    attrs: {
      "placement": "bottom-start",
      "trigger": "hover",
      "popper-class": "tiny-user-contact" + (_vm.showArrow ? " showArrow" : "") + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "append-to-body": _vm.popperAppendToBody,
      "visible-arrow": _vm.showArrow
    },
    on: {
      "show": function show($event) {
        _vm.show = true;
      },
      "hide": function hide($event) {
        _vm.show = false;
      }
    },
    scopedSlots: _vm._u([{
      key: "reference",
      fn: function fn() {
        return [_c("a", {
          staticClass: "dropdown-part",
          attrs: {
            "href": _vm.getUserHref()
          },
          on: {
            "click": _vm.doUserAction
          }
        }, [_c("user-head", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showImg,
            expression: "showImg"
          }],
          attrs: {
            "min": true,
            "round": true,
            "type": "image"
          },
          model: {
            value: _vm.data.imgUrl,
            callback: function callback($$v) {
              _vm.$set(_vm.data, "imgUrl", $$v);
            },
            expression: "data.imgUrl"
          }
        }), _c("div", {
          staticClass: "tiny-user-contact__role"
        }, [_c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showName,
            expression: "showName"
          }],
          staticClass: "tiny-user-contact__role-name"
        }, [_vm._v(_vm._s(_vm.data.userName))]), _c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showNumber,
            expression: "showNumber"
          }],
          staticClass: "tiny-user-contact__role-number"
        }, [_vm._v(_vm._s(_vm.data.roleNumber))])])], 1), _c(_vm.show ? "icon-chevron-up" : "icon-chevron-down", {
          tag: "component",
          staticClass: "tiny-svg-size tiny-user-contact__arrow"
        })];
      },
      proxy: true
    }])
  }, [_vm.slots.default ? _c("card-template", {
    staticClass: "tiny-user-contact__main",
    attrs: {
      "tools": _vm.data.tools
    }
  }, [_vm._t("default")], 2) : _c("card-template", {
    staticClass: "tiny-user-contact__main",
    attrs: {
      "tools": _vm.data.tools
    },
    scopedSlots: _vm._u([{
      key: "header",
      fn: function fn() {
        return [_c("div", {
          staticClass: "tiny-user-contact__header"
        }, [_c("div", {
          staticClass: "tiny-user-contact__title"
        }, [_c("user-head", {
          attrs: {
            "round": true,
            "type": "image"
          },
          model: {
            value: _vm.data.imgUrl,
            callback: function callback($$v) {
              _vm.$set(_vm.data, "imgUrl", $$v);
            },
            expression: "data.imgUrl"
          }
        }), _c("div", {
          staticClass: "tiny-user-contact__role"
        }, [_c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showName,
            expression: "showName"
          }],
          staticClass: "tiny-user-contact__role-name"
        }, [_vm._v(_vm._s(_vm.data.userName))]), _c("span", {
          directives: [{
            name: "show",
            rawName: "v-show",
            value: _vm.showNumber,
            expression: "showNumber"
          }],
          staticClass: "tiny-user-contact__role-number"
        }, [_vm._v(" " + _vm._s(_vm.t("ui.usercard.empno")) + "：" + _vm._s(_vm.data.roleNumber) + " ")])])], 1)])];
      },
      proxy: true
    }])
  }, [_c("div", [_c("div", {
    staticClass: "tiny-user-contact__message"
  }, _vm._l(_vm.data.values, function(item) {
    return _c("div", {
      key: item.text,
      staticClass: "tiny-user-contact__state"
    }, [_c("span", {
      staticClass: "tiny-user-contact__state-left"
    }, [_vm._v(_vm._s(item.text) + "：")]), _c("span", {
      staticClass: "tiny-user-contact__state-right"
    }, [_vm._v(_vm._s(item.value))])]);
  }), 0), _vm.espace && _vm.espace.length ? _c("espace", {
    attrs: {
      "data": _vm.espace
    }
  }) : _vm._e()], 1)])], 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
